:github_url: https://github.com/tasts-robots/ltv-mpc/tree/master/doc/src/usage.rst

*****
Usage
*****

Defining a problem
==================

.. automodule:: ltv_mpc.problem
    :members:

Solving the problem
===================

.. autofunction:: ltv_mpc.solve_mpc.solve_mpc

Reading the solution
====================

.. automodule:: ltv_mpc.solution
    :members:
